/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.autoscaling.model;

import java.io.Serializable;

/**
 * <p>
 * Describes a metric.
 * </p>
 */
public class MetricCollectionType implements Serializable, Cloneable {

    /**
     * The metric. <ul> <li><p><code>GroupMinSize</code></li>
     * <li><p><code>GroupMaxSize</code></li>
     * <li><p><code>GroupDesiredCapacity</code></li>
     * <li><p><code>GroupInServiceInstances</code></li>
     * <li><p><code>GroupPendingInstances</code></li>
     * <li><p><code>GroupStandbyInstances</code></li>
     * <li><p><code>GroupTerminatingInstances</code></li>
     * <li><p><code>GroupTotalInstances</code></li> </ul>
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>1 - 255<br/>
     * <b>Pattern: </b>[&#92;u0020-&#92;uD7FF&#92;uE000-&#92;uFFFD&#92;uD800&#92;uDC00-&#92;uDBFF&#92;uDFFF\r\n\t]*<br/>
     */
    private String metric;

    /**
     * The metric. <ul> <li><p><code>GroupMinSize</code></li>
     * <li><p><code>GroupMaxSize</code></li>
     * <li><p><code>GroupDesiredCapacity</code></li>
     * <li><p><code>GroupInServiceInstances</code></li>
     * <li><p><code>GroupPendingInstances</code></li>
     * <li><p><code>GroupStandbyInstances</code></li>
     * <li><p><code>GroupTerminatingInstances</code></li>
     * <li><p><code>GroupTotalInstances</code></li> </ul>
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>1 - 255<br/>
     * <b>Pattern: </b>[&#92;u0020-&#92;uD7FF&#92;uE000-&#92;uFFFD&#92;uD800&#92;uDC00-&#92;uDBFF&#92;uDFFF\r\n\t]*<br/>
     *
     * @return The metric. <ul> <li><p><code>GroupMinSize</code></li>
     *         <li><p><code>GroupMaxSize</code></li>
     *         <li><p><code>GroupDesiredCapacity</code></li>
     *         <li><p><code>GroupInServiceInstances</code></li>
     *         <li><p><code>GroupPendingInstances</code></li>
     *         <li><p><code>GroupStandbyInstances</code></li>
     *         <li><p><code>GroupTerminatingInstances</code></li>
     *         <li><p><code>GroupTotalInstances</code></li> </ul>
     */
    public String getMetric() {
        return metric;
    }
    
    /**
     * The metric. <ul> <li><p><code>GroupMinSize</code></li>
     * <li><p><code>GroupMaxSize</code></li>
     * <li><p><code>GroupDesiredCapacity</code></li>
     * <li><p><code>GroupInServiceInstances</code></li>
     * <li><p><code>GroupPendingInstances</code></li>
     * <li><p><code>GroupStandbyInstances</code></li>
     * <li><p><code>GroupTerminatingInstances</code></li>
     * <li><p><code>GroupTotalInstances</code></li> </ul>
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>1 - 255<br/>
     * <b>Pattern: </b>[&#92;u0020-&#92;uD7FF&#92;uE000-&#92;uFFFD&#92;uD800&#92;uDC00-&#92;uDBFF&#92;uDFFF\r\n\t]*<br/>
     *
     * @param metric The metric. <ul> <li><p><code>GroupMinSize</code></li>
     *         <li><p><code>GroupMaxSize</code></li>
     *         <li><p><code>GroupDesiredCapacity</code></li>
     *         <li><p><code>GroupInServiceInstances</code></li>
     *         <li><p><code>GroupPendingInstances</code></li>
     *         <li><p><code>GroupStandbyInstances</code></li>
     *         <li><p><code>GroupTerminatingInstances</code></li>
     *         <li><p><code>GroupTotalInstances</code></li> </ul>
     */
    public void setMetric(String metric) {
        this.metric = metric;
    }
    
    /**
     * The metric. <ul> <li><p><code>GroupMinSize</code></li>
     * <li><p><code>GroupMaxSize</code></li>
     * <li><p><code>GroupDesiredCapacity</code></li>
     * <li><p><code>GroupInServiceInstances</code></li>
     * <li><p><code>GroupPendingInstances</code></li>
     * <li><p><code>GroupStandbyInstances</code></li>
     * <li><p><code>GroupTerminatingInstances</code></li>
     * <li><p><code>GroupTotalInstances</code></li> </ul>
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>1 - 255<br/>
     * <b>Pattern: </b>[&#92;u0020-&#92;uD7FF&#92;uE000-&#92;uFFFD&#92;uD800&#92;uDC00-&#92;uDBFF&#92;uDFFF\r\n\t]*<br/>
     *
     * @param metric The metric. <ul> <li><p><code>GroupMinSize</code></li>
     *         <li><p><code>GroupMaxSize</code></li>
     *         <li><p><code>GroupDesiredCapacity</code></li>
     *         <li><p><code>GroupInServiceInstances</code></li>
     *         <li><p><code>GroupPendingInstances</code></li>
     *         <li><p><code>GroupStandbyInstances</code></li>
     *         <li><p><code>GroupTerminatingInstances</code></li>
     *         <li><p><code>GroupTotalInstances</code></li> </ul>
     *
     * @return A reference to this updated object so that method calls can be chained
     *         together.
     */
    public MetricCollectionType withMetric(String metric) {
        this.metric = metric;
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getMetric() != null) sb.append("Metric: " + getMetric() );
        sb.append("}");
        return sb.toString();
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;
        
        hashCode = prime * hashCode + ((getMetric() == null) ? 0 : getMetric().hashCode()); 
        return hashCode;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;

        if (obj instanceof MetricCollectionType == false) return false;
        MetricCollectionType other = (MetricCollectionType)obj;
        
        if (other.getMetric() == null ^ this.getMetric() == null) return false;
        if (other.getMetric() != null && other.getMetric().equals(this.getMetric()) == false) return false; 
        return true;
    }
    
    @Override
    public MetricCollectionType clone() {
        try {
            return (MetricCollectionType) super.clone();
        
        } catch (CloneNotSupportedException e) {
            throw new IllegalStateException(
                    "Got a CloneNotSupportedException from Object.clone() "
                    + "even though we're Cloneable!",
                    e);
        }
        
    }

}
    