/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.codedeploy.model;

import java.io.Serializable;

import com.amazonaws.AmazonWebServiceRequest;

/**
 * Container for the parameters to the {@link com.amazonaws.services.codedeploy.AmazonCodeDeploy#deleteDeploymentConfig(DeleteDeploymentConfigRequest) DeleteDeploymentConfig operation}.
 * <p>
 * Deletes a deployment configuration.
 * </p>
 * <p>
 * <b>NOTE:</b>A deployment configuration cannot be deleted if it is
 * currently in use. Also, predefined configurations cannot be deleted.
 * </p>
 *
 * @see com.amazonaws.services.codedeploy.AmazonCodeDeploy#deleteDeploymentConfig(DeleteDeploymentConfigRequest)
 */
public class DeleteDeploymentConfigRequest extends AmazonWebServiceRequest implements Serializable, Cloneable {

    /**
     * The name of an existing deployment configuration associated with the
     * applicable IAM user or AWS account.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>1 - 100<br/>
     */
    private String deploymentConfigName;

    /**
     * The name of an existing deployment configuration associated with the
     * applicable IAM user or AWS account.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>1 - 100<br/>
     *
     * @return The name of an existing deployment configuration associated with the
     *         applicable IAM user or AWS account.
     */
    public String getDeploymentConfigName() {
        return deploymentConfigName;
    }
    
    /**
     * The name of an existing deployment configuration associated with the
     * applicable IAM user or AWS account.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>1 - 100<br/>
     *
     * @param deploymentConfigName The name of an existing deployment configuration associated with the
     *         applicable IAM user or AWS account.
     */
    public void setDeploymentConfigName(String deploymentConfigName) {
        this.deploymentConfigName = deploymentConfigName;
    }
    
    /**
     * The name of an existing deployment configuration associated with the
     * applicable IAM user or AWS account.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Length: </b>1 - 100<br/>
     *
     * @param deploymentConfigName The name of an existing deployment configuration associated with the
     *         applicable IAM user or AWS account.
     *
     * @return A reference to this updated object so that method calls can be chained
     *         together.
     */
    public DeleteDeploymentConfigRequest withDeploymentConfigName(String deploymentConfigName) {
        this.deploymentConfigName = deploymentConfigName;
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getDeploymentConfigName() != null) sb.append("DeploymentConfigName: " + getDeploymentConfigName() );
        sb.append("}");
        return sb.toString();
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;
        
        hashCode = prime * hashCode + ((getDeploymentConfigName() == null) ? 0 : getDeploymentConfigName().hashCode()); 
        return hashCode;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;

        if (obj instanceof DeleteDeploymentConfigRequest == false) return false;
        DeleteDeploymentConfigRequest other = (DeleteDeploymentConfigRequest)obj;
        
        if (other.getDeploymentConfigName() == null ^ this.getDeploymentConfigName() == null) return false;
        if (other.getDeploymentConfigName() != null && other.getDeploymentConfigName().equals(this.getDeploymentConfigName()) == false) return false; 
        return true;
    }
    
    @Override
    public DeleteDeploymentConfigRequest clone() {
        
            return (DeleteDeploymentConfigRequest) super.clone();
    }

}
    