/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.ec2.model;

import java.io.Serializable;

/**
 * <p>
 * Contains the output of DescribeSpotFleetRequests.
 * </p>
 */
public class DescribeSpotFleetRequestsResult implements Serializable, Cloneable {

    /**
     * Information about the configuration of your Spot fleet.
     */
    private com.amazonaws.internal.ListWithAutoConstructFlag<SpotFleetRequestConfig> spotFleetRequestConfigs;

    /**
     * The token required to retrieve the next set of results. This value is
     * <code>null</code> when there are no more results to return.
     */
    private String nextToken;

    /**
     * Information about the configuration of your Spot fleet.
     *
     * @return Information about the configuration of your Spot fleet.
     */
    public java.util.List<SpotFleetRequestConfig> getSpotFleetRequestConfigs() {
        if (spotFleetRequestConfigs == null) {
              spotFleetRequestConfigs = new com.amazonaws.internal.ListWithAutoConstructFlag<SpotFleetRequestConfig>();
              spotFleetRequestConfigs.setAutoConstruct(true);
        }
        return spotFleetRequestConfigs;
    }
    
    /**
     * Information about the configuration of your Spot fleet.
     *
     * @param spotFleetRequestConfigs Information about the configuration of your Spot fleet.
     */
    public void setSpotFleetRequestConfigs(java.util.Collection<SpotFleetRequestConfig> spotFleetRequestConfigs) {
        if (spotFleetRequestConfigs == null) {
            this.spotFleetRequestConfigs = null;
            return;
        }
        com.amazonaws.internal.ListWithAutoConstructFlag<SpotFleetRequestConfig> spotFleetRequestConfigsCopy = new com.amazonaws.internal.ListWithAutoConstructFlag<SpotFleetRequestConfig>(spotFleetRequestConfigs.size());
        spotFleetRequestConfigsCopy.addAll(spotFleetRequestConfigs);
        this.spotFleetRequestConfigs = spotFleetRequestConfigsCopy;
    }
    
    /**
     * Information about the configuration of your Spot fleet.
     * <p>
     * <b>NOTE:</b> This method appends the values to the existing list (if
     * any). Use {@link #setSpotFleetRequestConfigs(java.util.Collection)} or
     * {@link #withSpotFleetRequestConfigs(java.util.Collection)} if you want
     * to override the existing values.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param spotFleetRequestConfigs Information about the configuration of your Spot fleet.
     *
     * @return A reference to this updated object so that method calls can be chained
     *         together.
     */
    public DescribeSpotFleetRequestsResult withSpotFleetRequestConfigs(SpotFleetRequestConfig... spotFleetRequestConfigs) {
        if (getSpotFleetRequestConfigs() == null) setSpotFleetRequestConfigs(new java.util.ArrayList<SpotFleetRequestConfig>(spotFleetRequestConfigs.length));
        for (SpotFleetRequestConfig value : spotFleetRequestConfigs) {
            getSpotFleetRequestConfigs().add(value);
        }
        return this;
    }
    
    /**
     * Information about the configuration of your Spot fleet.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param spotFleetRequestConfigs Information about the configuration of your Spot fleet.
     *
     * @return A reference to this updated object so that method calls can be chained
     *         together.
     */
    public DescribeSpotFleetRequestsResult withSpotFleetRequestConfigs(java.util.Collection<SpotFleetRequestConfig> spotFleetRequestConfigs) {
        if (spotFleetRequestConfigs == null) {
            this.spotFleetRequestConfigs = null;
        } else {
            com.amazonaws.internal.ListWithAutoConstructFlag<SpotFleetRequestConfig> spotFleetRequestConfigsCopy = new com.amazonaws.internal.ListWithAutoConstructFlag<SpotFleetRequestConfig>(spotFleetRequestConfigs.size());
            spotFleetRequestConfigsCopy.addAll(spotFleetRequestConfigs);
            this.spotFleetRequestConfigs = spotFleetRequestConfigsCopy;
        }

        return this;
    }

    /**
     * The token required to retrieve the next set of results. This value is
     * <code>null</code> when there are no more results to return.
     *
     * @return The token required to retrieve the next set of results. This value is
     *         <code>null</code> when there are no more results to return.
     */
    public String getNextToken() {
        return nextToken;
    }
    
    /**
     * The token required to retrieve the next set of results. This value is
     * <code>null</code> when there are no more results to return.
     *
     * @param nextToken The token required to retrieve the next set of results. This value is
     *         <code>null</code> when there are no more results to return.
     */
    public void setNextToken(String nextToken) {
        this.nextToken = nextToken;
    }
    
    /**
     * The token required to retrieve the next set of results. This value is
     * <code>null</code> when there are no more results to return.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param nextToken The token required to retrieve the next set of results. This value is
     *         <code>null</code> when there are no more results to return.
     *
     * @return A reference to this updated object so that method calls can be chained
     *         together.
     */
    public DescribeSpotFleetRequestsResult withNextToken(String nextToken) {
        this.nextToken = nextToken;
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getSpotFleetRequestConfigs() != null) sb.append("SpotFleetRequestConfigs: " + getSpotFleetRequestConfigs() + ",");
        if (getNextToken() != null) sb.append("NextToken: " + getNextToken() );
        sb.append("}");
        return sb.toString();
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;
        
        hashCode = prime * hashCode + ((getSpotFleetRequestConfigs() == null) ? 0 : getSpotFleetRequestConfigs().hashCode()); 
        hashCode = prime * hashCode + ((getNextToken() == null) ? 0 : getNextToken().hashCode()); 
        return hashCode;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;

        if (obj instanceof DescribeSpotFleetRequestsResult == false) return false;
        DescribeSpotFleetRequestsResult other = (DescribeSpotFleetRequestsResult)obj;
        
        if (other.getSpotFleetRequestConfigs() == null ^ this.getSpotFleetRequestConfigs() == null) return false;
        if (other.getSpotFleetRequestConfigs() != null && other.getSpotFleetRequestConfigs().equals(this.getSpotFleetRequestConfigs()) == false) return false; 
        if (other.getNextToken() == null ^ this.getNextToken() == null) return false;
        if (other.getNextToken() != null && other.getNextToken().equals(this.getNextToken()) == false) return false; 
        return true;
    }
    
    @Override
    public DescribeSpotFleetRequestsResult clone() {
        try {
            return (DescribeSpotFleetRequestsResult) super.clone();
        
        } catch (CloneNotSupportedException e) {
            throw new IllegalStateException(
                    "Got a CloneNotSupportedException from Object.clone() "
                    + "even though we're Cloneable!",
                    e);
        }
        
    }

}
    