/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.ecs.model;

import java.io.Serializable;

/**
 * 
 */
public class KeyValuePair implements Serializable, Cloneable {

    /**
     * The name of the key value pair.
     */
    private String name;

    /**
     * The value of the key value pair.
     */
    private String value;

    /**
     * The name of the key value pair.
     *
     * @return The name of the key value pair.
     */
    public String getName() {
        return name;
    }
    
    /**
     * The name of the key value pair.
     *
     * @param name The name of the key value pair.
     */
    public void setName(String name) {
        this.name = name;
    }
    
    /**
     * The name of the key value pair.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param name The name of the key value pair.
     *
     * @return A reference to this updated object so that method calls can be chained
     *         together.
     */
    public KeyValuePair withName(String name) {
        this.name = name;
        return this;
    }

    /**
     * The value of the key value pair.
     *
     * @return The value of the key value pair.
     */
    public String getValue() {
        return value;
    }
    
    /**
     * The value of the key value pair.
     *
     * @param value The value of the key value pair.
     */
    public void setValue(String value) {
        this.value = value;
    }
    
    /**
     * The value of the key value pair.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param value The value of the key value pair.
     *
     * @return A reference to this updated object so that method calls can be chained
     *         together.
     */
    public KeyValuePair withValue(String value) {
        this.value = value;
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getName() != null) sb.append("Name: " + getName() + ",");
        if (getValue() != null) sb.append("Value: " + getValue() );
        sb.append("}");
        return sb.toString();
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;
        
        hashCode = prime * hashCode + ((getName() == null) ? 0 : getName().hashCode()); 
        hashCode = prime * hashCode + ((getValue() == null) ? 0 : getValue().hashCode()); 
        return hashCode;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;

        if (obj instanceof KeyValuePair == false) return false;
        KeyValuePair other = (KeyValuePair)obj;
        
        if (other.getName() == null ^ this.getName() == null) return false;
        if (other.getName() != null && other.getName().equals(this.getName()) == false) return false; 
        if (other.getValue() == null ^ this.getValue() == null) return false;
        if (other.getValue() != null && other.getValue().equals(this.getValue()) == false) return false; 
        return true;
    }
    
    @Override
    public KeyValuePair clone() {
        try {
            return (KeyValuePair) super.clone();
        
        } catch (CloneNotSupportedException e) {
            throw new IllegalStateException(
                    "Got a CloneNotSupportedException from Object.clone() "
                    + "even though we're Cloneable!",
                    e);
        }
        
    }

}
    