/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.elasticache.model;

import java.io.Serializable;

/**
 * <p>
 * Represents the output of a <i>DescribeCacheClusters</i> action.
 * </p>
 */
public class DescribeCacheClustersResult implements Serializable, Cloneable {

    /**
     * Provides an identifier to allow retrieval of paginated results.
     */
    private String marker;

    /**
     * A list of cache clusters. Each item in the list contains detailed
     * information about one cache cluster.
     */
    private com.amazonaws.internal.ListWithAutoConstructFlag<CacheCluster> cacheClusters;

    /**
     * Provides an identifier to allow retrieval of paginated results.
     *
     * @return Provides an identifier to allow retrieval of paginated results.
     */
    public String getMarker() {
        return marker;
    }
    
    /**
     * Provides an identifier to allow retrieval of paginated results.
     *
     * @param marker Provides an identifier to allow retrieval of paginated results.
     */
    public void setMarker(String marker) {
        this.marker = marker;
    }
    
    /**
     * Provides an identifier to allow retrieval of paginated results.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param marker Provides an identifier to allow retrieval of paginated results.
     *
     * @return A reference to this updated object so that method calls can be chained
     *         together.
     */
    public DescribeCacheClustersResult withMarker(String marker) {
        this.marker = marker;
        return this;
    }

    /**
     * A list of cache clusters. Each item in the list contains detailed
     * information about one cache cluster.
     *
     * @return A list of cache clusters. Each item in the list contains detailed
     *         information about one cache cluster.
     */
    public java.util.List<CacheCluster> getCacheClusters() {
        if (cacheClusters == null) {
              cacheClusters = new com.amazonaws.internal.ListWithAutoConstructFlag<CacheCluster>();
              cacheClusters.setAutoConstruct(true);
        }
        return cacheClusters;
    }
    
    /**
     * A list of cache clusters. Each item in the list contains detailed
     * information about one cache cluster.
     *
     * @param cacheClusters A list of cache clusters. Each item in the list contains detailed
     *         information about one cache cluster.
     */
    public void setCacheClusters(java.util.Collection<CacheCluster> cacheClusters) {
        if (cacheClusters == null) {
            this.cacheClusters = null;
            return;
        }
        com.amazonaws.internal.ListWithAutoConstructFlag<CacheCluster> cacheClustersCopy = new com.amazonaws.internal.ListWithAutoConstructFlag<CacheCluster>(cacheClusters.size());
        cacheClustersCopy.addAll(cacheClusters);
        this.cacheClusters = cacheClustersCopy;
    }
    
    /**
     * A list of cache clusters. Each item in the list contains detailed
     * information about one cache cluster.
     * <p>
     * <b>NOTE:</b> This method appends the values to the existing list (if
     * any). Use {@link #setCacheClusters(java.util.Collection)} or {@link
     * #withCacheClusters(java.util.Collection)} if you want to override the
     * existing values.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param cacheClusters A list of cache clusters. Each item in the list contains detailed
     *         information about one cache cluster.
     *
     * @return A reference to this updated object so that method calls can be chained
     *         together.
     */
    public DescribeCacheClustersResult withCacheClusters(CacheCluster... cacheClusters) {
        if (getCacheClusters() == null) setCacheClusters(new java.util.ArrayList<CacheCluster>(cacheClusters.length));
        for (CacheCluster value : cacheClusters) {
            getCacheClusters().add(value);
        }
        return this;
    }
    
    /**
     * A list of cache clusters. Each item in the list contains detailed
     * information about one cache cluster.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param cacheClusters A list of cache clusters. Each item in the list contains detailed
     *         information about one cache cluster.
     *
     * @return A reference to this updated object so that method calls can be chained
     *         together.
     */
    public DescribeCacheClustersResult withCacheClusters(java.util.Collection<CacheCluster> cacheClusters) {
        if (cacheClusters == null) {
            this.cacheClusters = null;
        } else {
            com.amazonaws.internal.ListWithAutoConstructFlag<CacheCluster> cacheClustersCopy = new com.amazonaws.internal.ListWithAutoConstructFlag<CacheCluster>(cacheClusters.size());
            cacheClustersCopy.addAll(cacheClusters);
            this.cacheClusters = cacheClustersCopy;
        }

        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getMarker() != null) sb.append("Marker: " + getMarker() + ",");
        if (getCacheClusters() != null) sb.append("CacheClusters: " + getCacheClusters() );
        sb.append("}");
        return sb.toString();
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;
        
        hashCode = prime * hashCode + ((getMarker() == null) ? 0 : getMarker().hashCode()); 
        hashCode = prime * hashCode + ((getCacheClusters() == null) ? 0 : getCacheClusters().hashCode()); 
        return hashCode;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;

        if (obj instanceof DescribeCacheClustersResult == false) return false;
        DescribeCacheClustersResult other = (DescribeCacheClustersResult)obj;
        
        if (other.getMarker() == null ^ this.getMarker() == null) return false;
        if (other.getMarker() != null && other.getMarker().equals(this.getMarker()) == false) return false; 
        if (other.getCacheClusters() == null ^ this.getCacheClusters() == null) return false;
        if (other.getCacheClusters() != null && other.getCacheClusters().equals(this.getCacheClusters()) == false) return false; 
        return true;
    }
    
    @Override
    public DescribeCacheClustersResult clone() {
        try {
            return (DescribeCacheClustersResult) super.clone();
        
        } catch (CloneNotSupportedException e) {
            throw new IllegalStateException(
                    "Got a CloneNotSupportedException from Object.clone() "
                    + "even though we're Cloneable!",
                    e);
        }
        
    }

}
    